@@ -6,20 +6,20 @@
 
 #include "Link.h"
 
+#include "mozilla/Components.h"
 #include "mozilla/EventStates.h"
 #include "mozilla/MemoryReporting.h"
 #include "mozilla/dom/Element.h"
-#ifdef ANDROID
-#include "mozilla/IHistory.h"
+#if defined(MOZ_PLACES)
+#  include "mozilla/places/History.h"
 #else
-#include "mozilla/places/History.h"
+#  include "mozilla/IHistory.h"
 #endif
 #include "nsIURL.h"
 #include "nsIURIMutator.h"
 #include "nsISizeOf.h"
 #include "nsIDocShell.h"
 #include "nsIPrefetchService.h"
-#include "nsCPrefetchService.h"
 #include "nsStyleLinkElement.h"
 
 #include "nsEscape.h"
@@ -30,15 +30,16 @@
 
 #include "mozilla/Services.h"
 #include "nsAttrValueInlines.h"
+#include "HTMLLinkElement.h"
 
 namespace mozilla {
 namespace dom {
 
-#ifndef ANDROID
+#if defined(MOZ_PLACES)
 using places::History;
 #endif
 
-Link::Link(Element *aElement)
+Link::Link(Element* aElement)
     : mElement(aElement),
       mLinkState(eLinkState_NotLink),
       mNeedsRegistration(false),
@@ -94,10 +95,10 @@ void Link::CancelDNSPrefetch(nsWrapperCache::FlagsType aDeferredFlag,
   }
 }
 
-void Link::GetContentPolicyMimeTypeMedia(nsAttrValue &aAsAttr,
-                                         nsContentPolicyType &aPolicyType,
-                                         nsString &aMimeType,
-                                         nsAString &aMedia) {
+void Link::GetContentPolicyMimeTypeMedia(nsAttrValue& aAsAttr,
+                                         nsContentPolicyType& aPolicyType,
+                                         nsString& aMimeType,
+                                         nsAString& aMedia) {
   nsAutoString as;
   mElement->GetAttr(kNameSpaceID_None, nsGkAtoms::as, as);
   Link::ParseAsValue(as, aAsAttr);
@@ -133,11 +134,10 @@ void Link::TryDNSPrefetchOrPreconnectOrPrefetchOrPreloadOrPrerender() {
       (linkTypes & nsStyleLinkElement::eNEXT) ||
       (linkTypes & nsStyleLinkElement::ePRELOAD)) {
     nsCOMPtr<nsIPrefetchService> prefetchService(
-        do_GetService(NS_PREFETCHSERVICE_CONTRACTID));
+        components::Prefetch::Service());
     if (prefetchService) {
       nsCOMPtr<nsIURI> uri(GetURI());
       if (uri) {
-        nsCOMPtr<nsIDOMNode> domNode = GetAsDOMNode(mElement);
         if (linkTypes & nsStyleLinkElement::ePRELOAD) {
           nsAttrValue asAttr;
           nsContentPolicyType policyType;
@@ -150,16 +150,17 @@ void Link::TryDNSPrefetchOrPreconnectOrPrefetchOrPreloadOrPrerender() {
             return;
           }
 
-          if (!nsStyleLinkElement::CheckPreloadAttrs(asAttr, mimeType, media,
-                                                     mElement->OwnerDoc())) {
+          if (!HTMLLinkElement::CheckPreloadAttrs(asAttr, mimeType, media,
+                                                  mElement->OwnerDoc())) {
             policyType = nsIContentPolicy::TYPE_INVALID;
           }
 
-          prefetchService->PreloadURI(
-              uri, mElement->OwnerDoc()->GetDocumentURI(), domNode, policyType);
+          prefetchService->PreloadURI(uri,
+                                      mElement->OwnerDoc()->GetDocumentURI(),
+                                      mElement, policyType);
         } else {
           prefetchService->PrefetchURI(
-              uri, mElement->OwnerDoc()->GetDocumentURI(), domNode,
+              uri, mElement->OwnerDoc()->GetDocumentURI(), mElement,
               linkTypes & nsStyleLinkElement::ePREFETCH);
         }
         return;
@@ -171,7 +172,7 @@ void Link::TryDNSPrefetchOrPreconnectOrPrefetchOrPreloadOrPrerender() {
     nsCOMPtr<nsIURI> uri(GetURI());
     if (uri && mElement->OwnerDoc()) {
       mElement->OwnerDoc()->MaybePreconnect(
-          uri, mElement->AttrValueToCORSMode(
+          uri, Element::AttrValueToCORSMode(
                    mElement->GetParsedAttr(nsGkAtoms::crossorigin)));
       return;
     }
@@ -184,8 +185,8 @@ void Link::TryDNSPrefetchOrPreconnectOrPrefetchOrPreloadOrPrerender() {
   }
 }
 
-void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
-                         const nsAttrValue *aOldValue) {
+void Link::UpdatePreload(nsAtom* aName, const nsAttrValue* aValue,
+                         const nsAttrValue* aOldValue) {
   MOZ_ASSERT(mElement->IsInComposedDoc());
 
   if (!ElementHasHref()) {
@@ -208,8 +209,7 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
     return;
   }
 
-  nsCOMPtr<nsIPrefetchService> prefetchService(
-      do_GetService(NS_PREFETCHSERVICE_CONTRACTID));
+  nsCOMPtr<nsIPrefetchService> prefetchService(components::Prefetch::Service());
   if (!prefetchService) {
     return;
   }
@@ -219,8 +219,6 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
     return;
   }
 
-  nsCOMPtr<nsIDOMNode> domNode = GetAsDOMNode(mElement);
-
   nsAttrValue asAttr;
   nsContentPolicyType asPolicyType;
   nsAutoString mimeType;
@@ -230,13 +228,13 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
   if (asPolicyType == nsIContentPolicy::TYPE_INVALID) {
     // Ignore preload with a wrong or empty as attribute, but be sure to cancel
     // the old one.
-    prefetchService->CancelPrefetchPreloadURI(uri, domNode);
+    prefetchService->CancelPrefetchPreloadURI(uri, mElement);
     return;
   }
 
   nsContentPolicyType policyType = asPolicyType;
-  if (!nsStyleLinkElement::CheckPreloadAttrs(asAttr, mimeType, media,
-                                             mElement->OwnerDoc())) {
+  if (!HTMLLinkElement::CheckPreloadAttrs(asAttr, mimeType, media,
+                                          mElement->OwnerDoc())) {
     policyType = nsIContentPolicy::TYPE_INVALID;
   }
 
@@ -244,9 +242,9 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
     CORSMode corsMode = Element::AttrValueToCORSMode(aValue);
     CORSMode oldCorsMode = Element::AttrValueToCORSMode(aOldValue);
     if (corsMode != oldCorsMode) {
-      prefetchService->CancelPrefetchPreloadURI(uri, domNode);
+      prefetchService->CancelPrefetchPreloadURI(uri, mElement);
       prefetchService->PreloadURI(uri, mElement->OwnerDoc()->GetDocumentURI(),
-                                  domNode, policyType);
+                                  mElement, policyType);
     }
     return;
   }
@@ -256,8 +254,8 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
   if (aName == nsGkAtoms::as) {
     if (aOldValue) {
       oldPolicyType = AsValueToContentPolicy(*aOldValue);
-      if (!nsStyleLinkElement::CheckPreloadAttrs(*aOldValue, mimeType, media,
-                                                 mElement->OwnerDoc())) {
+      if (!HTMLLinkElement::CheckPreloadAttrs(*aOldValue, mimeType, media,
+                                              mElement->OwnerDoc())) {
         oldPolicyType = nsIContentPolicy::TYPE_INVALID;
       }
     } else {
@@ -273,8 +271,8 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
     }
     nsAutoString oldMimeType;
     nsContentUtils::SplitMimeType(oldType, oldMimeType, notUsed);
-    if (nsStyleLinkElement::CheckPreloadAttrs(asAttr, oldMimeType, media,
-                                              mElement->OwnerDoc())) {
+    if (HTMLLinkElement::CheckPreloadAttrs(asAttr, oldMimeType, media,
+                                           mElement->OwnerDoc())) {
       oldPolicyType = asPolicyType;
     } else {
       oldPolicyType = nsIContentPolicy::TYPE_INVALID;
@@ -287,8 +285,8 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
     } else {
       oldMedia = EmptyString();
     }
-    if (nsStyleLinkElement::CheckPreloadAttrs(asAttr, mimeType, oldMedia,
-                                              mElement->OwnerDoc())) {
+    if (HTMLLinkElement::CheckPreloadAttrs(asAttr, mimeType, oldMedia,
+                                           mElement->OwnerDoc())) {
       oldPolicyType = asPolicyType;
     } else {
       oldPolicyType = nsIContentPolicy::TYPE_INVALID;
@@ -297,7 +295,7 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
 
   if ((policyType != oldPolicyType) &&
       (oldPolicyType != nsIContentPolicy::TYPE_INVALID)) {
-    prefetchService->CancelPrefetchPreloadURI(uri, domNode);
+    prefetchService->CancelPrefetchPreloadURI(uri, mElement);
   }
 
   // Trigger a new preload if the policy type has changed.
@@ -306,18 +304,16 @@ void Link::UpdatePreload(nsAtom *aName, const nsAttrValue *aValue,
   if ((policyType != oldPolicyType) ||
       (policyType == nsIContentPolicy::TYPE_INVALID)) {
     prefetchService->PreloadURI(uri, mElement->OwnerDoc()->GetDocumentURI(),
-                                domNode, policyType);
+                                mElement, policyType);
   }
 }
 
 void Link::CancelPrefetchOrPreload() {
-  nsCOMPtr<nsIPrefetchService> prefetchService(
-      do_GetService(NS_PREFETCHSERVICE_CONTRACTID));
+  nsCOMPtr<nsIPrefetchService> prefetchService(components::Prefetch::Service());
   if (prefetchService) {
     nsCOMPtr<nsIURI> uri(GetURI());
     if (uri) {
-      nsCOMPtr<nsIDOMNode> domNode = GetAsDOMNode(mElement);
-      prefetchService->CancelPrefetchPreloadURI(uri, domNode);
+      prefetchService->CancelPrefetchPreloadURI(uri, mElement);
     }
   }
 }
@@ -344,9 +340,9 @@ void Link::SetLinkState(nsLinkState aState) {
 EventStates Link::LinkState() const {
   // We are a constant method, but we are just lazily doing things and have to
   // track that state.  Cast away that constness!
-  Link *self = const_cast<Link *>(this);
+  Link* self = const_cast<Link*>(this);
 
-  Element *element = self->mElement;
+  Element* element = self->mElement;
 
   // If we have not yet registered for notifications and need to,
   // due to our href changing, register now!
@@ -365,8 +361,10 @@ EventStates Link::LinkState() const {
     if (mHistory && hrefURI) {
 #ifdef ANDROID
       nsCOMPtr<IHistory> history = services::GetHistoryService();
+#elif defined(MOZ_PLACES)
+      History* history = History::GetService();
 #else
-      History *history = History::GetService();
+      nsCOMPtr<IHistory> history;
 #endif
       if (history) {
         nsresult rv = history->RegisterVisitedCallback(hrefURI, self);
@@ -392,21 +390,21 @@ EventStates Link::LinkState() const {
   return EventStates();
 }
 
-nsIURI *Link::GetURI() const {
+nsIURI* Link::GetURI() const {
   // If we have this URI cached, use it.
   if (mCachedURI) {
     return mCachedURI;
   }
 
   // Otherwise obtain it.
-  Link *self = const_cast<Link *>(this);
-  Element *element = self->mElement;
+  Link* self = const_cast<Link*>(this);
+  Element* element = self->mElement;
   mCachedURI = element->GetHrefURI();
 
   return mCachedURI;
 }
 
-void Link::SetProtocol(const nsAString &aProtocol) {
+void Link::SetProtocol(const nsAString& aProtocol) {
   nsCOMPtr<nsIURI> uri(GetURI());
   if (!uri) {
     // Ignore failures to be compatible with NS4.
@@ -428,7 +426,7 @@ void Link::SetProtocol(const nsAString &aProtocol) {
   SetHrefAttribute(uri);
 }
 
-void Link::SetPassword(const nsAString &aPassword) {
+void Link::SetPassword(const nsAString& aPassword) {
   nsCOMPtr<nsIURI> uri(GetURI());
   if (!uri) {
     // Ignore failures to be compatible with NS4.
@@ -443,7 +441,7 @@ void Link::SetPassword(const nsAString &aPassword) {
   }
 }
 
-void Link::SetUsername(const nsAString &aUsername) {
+void Link::SetUsername(const nsAString& aUsername) {
   nsCOMPtr<nsIURI> uri(GetURI());
   if (!uri) {
     // Ignore failures to be compatible with NS4.
@@ -458,7 +456,7 @@ void Link::SetUsername(const nsAString &aUsername) {
   }
 }
 
-void Link::SetHost(const nsAString &aHost) {
+void Link::SetHost(const nsAString& aHost) {
   nsCOMPtr<nsIURI> uri(GetURI());
   if (!uri) {
     // Ignore failures to be compatible with NS4.
@@ -473,7 +471,7 @@ void Link::SetHost(const nsAString &aHost) {
   SetHrefAttribute(uri);
 }
 
-void Link::SetHostname(const nsAString &aHostname) {
+void Link::SetHostname(const nsAString& aHostname) {
   nsCOMPtr<nsIURI> uri(GetURI());
   if (!uri) {
     // Ignore failures to be compatible with NS4.
@@ -488,7 +486,7 @@ void Link::SetHostname(const nsAString &aHostname) {
   SetHrefAttribute(uri);
 }
 
-void Link::SetPathname(const nsAString &aPathname) {
+void Link::SetPathname(const nsAString& aPathname) {
   nsCOMPtr<nsIURI> uri(GetURI());
   nsCOMPtr<nsIURL> url(do_QueryInterface(uri));
   if (!url) {
@@ -505,7 +503,7 @@ void Link::SetPathname(const nsAString &aPathname) {
   SetHrefAttribute(uri);
 }
 
-void Link::SetSearch(const nsAString &aSearch) {
+void Link::SetSearch(const nsAString& aSearch) {
   nsCOMPtr<nsIURI> uri(GetURI());
   nsCOMPtr<nsIURL> url(do_QueryInterface(uri));
   if (!url) {
@@ -524,7 +522,7 @@ void Link::SetSearch(const nsAString &aSearch) {
   SetHrefAttribute(uri);
 }
 
-void Link::SetPort(const nsAString &aPort) {
+void Link::SetPort(const nsAString& aPort) {
   nsCOMPtr<nsIURI> uri(GetURI());
   if (!uri) {
     // Ignore failures to be compatible with NS4.
@@ -550,7 +548,7 @@ void Link::SetPort(const nsAString &aPort) {
   SetHrefAttribute(uri);
 }
 
-void Link::SetHash(const nsAString &aHash) {
+void Link::SetHash(const nsAString& aHash) {
   nsCOMPtr<nsIURI> uri(GetURI());
   if (!uri) {
     // Ignore failures to be compatible with NS4.
@@ -566,7 +564,7 @@ void Link::SetHash(const nsAString &aHash) {
   SetHrefAttribute(uri);
 }
 
-void Link::GetOrigin(nsAString &aOrigin) {
+void Link::GetOrigin(nsAString& aOrigin) {
   aOrigin.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -579,7 +577,7 @@ void Link::GetOrigin(nsAString &aOrigin) {
   aOrigin.Assign(origin);
 }
 
-void Link::GetProtocol(nsAString &_protocol) {
+void Link::GetProtocol(nsAString& _protocol) {
   nsCOMPtr<nsIURI> uri(GetURI());
   if (!uri) {
     _protocol.AssignLiteral("http");
@@ -591,7 +589,7 @@ void Link::GetProtocol(nsAString &_protocol) {
   _protocol.Append(char16_t(':'));
 }
 
-void Link::GetUsername(nsAString &aUsername) {
+void Link::GetUsername(nsAString& aUsername) {
   aUsername.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -604,7 +602,7 @@ void Link::GetUsername(nsAString &aUsername) {
   CopyASCIItoUTF16(username, aUsername);
 }
 
-void Link::GetPassword(nsAString &aPassword) {
+void Link::GetPassword(nsAString& aPassword) {
   aPassword.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -617,7 +615,7 @@ void Link::GetPassword(nsAString &aPassword) {
   CopyASCIItoUTF16(password, aPassword);
 }
 
-void Link::GetHost(nsAString &_host) {
+void Link::GetHost(nsAString& _host) {
   _host.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -633,7 +631,7 @@ void Link::GetHost(nsAString &_host) {
   }
 }
 
-void Link::GetHostname(nsAString &_hostname) {
+void Link::GetHostname(nsAString& _hostname) {
   _hostname.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -645,7 +643,7 @@ void Link::GetHostname(nsAString &_hostname) {
   nsContentUtils::GetHostOrIPv6WithBrackets(uri, _hostname);
 }
 
-void Link::GetPathname(nsAString &_pathname) {
+void Link::GetPathname(nsAString& _pathname) {
   _pathname.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -663,7 +661,7 @@ void Link::GetPathname(nsAString &_pathname) {
   }
 }
 
-void Link::GetSearch(nsAString &_search) {
+void Link::GetSearch(nsAString& _search) {
   _search.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -677,11 +675,12 @@ void Link::GetSearch(nsAString &_search) {
   nsAutoCString search;
   nsresult rv = url->GetQuery(search);
   if (NS_SUCCEEDED(rv) && !search.IsEmpty()) {
-    CopyUTF8toUTF16(NS_LITERAL_CSTRING("?") + search, _search);
+    _search.Assign(u'?');
+    AppendUTF8toUTF16(search, _search);
   }
 }
 
-void Link::GetPort(nsAString &_port) {
+void Link::GetPort(nsAString& _port) {
   _port.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -701,7 +700,7 @@ void Link::GetPort(nsAString &_port) {
   }
 }
 
-void Link::GetHash(nsAString &_hash) {
+void Link::GetHash(nsAString& _hash) {
   _hash.Truncate();
 
   nsCOMPtr<nsIURI> uri(GetURI());
@@ -733,7 +732,7 @@ void Link::ResetLinkState(bool aNotify, bool aHasHref) {
   // currently registered; in either case, we should remove ourself
   // from the doc and the history.
   if (!mNeedsRegistration && mLinkState != eLinkState_NotLink) {
-    nsIDocument *doc = mElement->GetComposedDoc();
+    Document* doc = mElement->GetComposedDoc();
     if (doc && (mRegistered || mLinkState == eLinkState_Visited)) {
       // Tell the document to forget about this link if we've registered
       // with it before.
@@ -780,8 +779,10 @@ void Link::UnregisterFromHistory() {
   if (mHistory && mCachedURI) {
 #ifdef ANDROID
     nsCOMPtr<IHistory> history = services::GetHistoryService();
+#elif defined(MOZ_PLACES)
+    History* history = History::GetService();
 #else
-    History *history = History::GetService();
+    nsCOMPtr<IHistory> history;
 #endif
     if (history) {
       nsresult rv = history->UnregisterVisitedCallback(mCachedURI, this);
@@ -794,18 +795,7 @@ void Link::UnregisterFromHistory() {
   }
 }
 
-already_AddRefed<nsIURI> Link::GetURIToMutate() {
-  MOZ_ASSERT(false, "TODO: REMOVE THIS METHOD");
-  nsCOMPtr<nsIURI> uri(GetURI());
-  if (!uri) {
-    return nullptr;
-  }
-  nsCOMPtr<nsIURI> clone;
-  (void)uri->Clone(getter_AddRefs(clone));
-  return clone.forget();
-}
-
-void Link::SetHrefAttribute(nsIURI *aURI) {
+void Link::SetHrefAttribute(nsIURI* aURI) {
   NS_ASSERTION(aURI, "Null URI is illegal!");
 
   // if we change this code to not reserialize we need to do something smarter
@@ -817,7 +807,7 @@ void Link::SetHrefAttribute(nsIURI *aURI) {
                           NS_ConvertUTF8toUTF16(href), true);
 }
 
-size_t Link::SizeOfExcludingThis(mozilla::SizeOfState &aState) const {
+size_t Link::SizeOfExcludingThis(mozilla::SizeOfState& aState) const {
   size_t n = 0;
 
   if (mCachedURI) {
@@ -840,8 +830,8 @@ static const nsAttrValue::EnumTable kAsAttributeTable[] = {
     {"track", DESTINATION_TRACK},   {"video", DESTINATION_VIDEO},
     {"fetch", DESTINATION_FETCH},   {nullptr, 0}};
 
-/* static */ void Link::ParseAsValue(const nsAString &aValue,
-                                     nsAttrValue &aResult) {
+/* static */
+void Link::ParseAsValue(const nsAString& aValue, nsAttrValue& aResult) {
   DebugOnly<bool> success =
       aResult.ParseEnumValue(aValue, kAsAttributeTable, false,
                              // default value is a empty string
@@ -851,15 +841,17 @@ static const nsAttrValue::EnumTable kAsAttributeTable[] = {
   MOZ_ASSERT(success);
 }
 
-/* static */ nsContentPolicyType Link::AsValueToContentPolicy(
-    const nsAttrValue &aValue) {
+/* static */
+nsContentPolicyType Link::AsValueToContentPolicy(const nsAttrValue& aValue) {
   switch (aValue.GetEnumValue()) {
     case DESTINATION_INVALID:
       return nsIContentPolicy::TYPE_INVALID;
     case DESTINATION_AUDIO:
+      return nsIContentPolicy::TYPE_INTERNAL_AUDIO;
     case DESTINATION_TRACK:
+      return nsIContentPolicy::TYPE_INTERNAL_TRACK;
     case DESTINATION_VIDEO:
-      return nsIContentPolicy::TYPE_MEDIA;
+      return nsIContentPolicy::TYPE_INTERNAL_VIDEO;
     case DESTINATION_FONT:
       return nsIContentPolicy::TYPE_FONT;
     case DESTINATION_IMAGE:
