@@ -16,8 +16,8 @@ namespace mozilla {
 namespace dom {
 
 HTMLTimeElement::HTMLTimeElement(
-    already_AddRefed<mozilla::dom::NodeInfo>& aNodeInfo)
-    : nsGenericHTMLElement(aNodeInfo) {}
+    already_AddRefed<mozilla::dom::NodeInfo>&& aNodeInfo)
+    : nsGenericHTMLElement(std::move(aNodeInfo)) {}
 
 HTMLTimeElement::~HTMLTimeElement() {}
 
@@ -25,7 +25,7 @@ NS_IMPL_ELEMENT_CLONE(HTMLTimeElement)
 
 JSObject* HTMLTimeElement::WrapNode(JSContext* cx,
                                     JS::Handle<JSObject*> aGivenProto) {
-  return HTMLTimeElementBinding::Wrap(cx, this, aGivenProto);
+  return HTMLTimeElement_Binding::Wrap(cx, this, aGivenProto);
 }
 
 }  // namespace dom
